[Scummvm-cvs-logs] scummvm master -> a4ef3f9d7305783a3cc8068cb5dbc978a7f22f1c

bluegr bluegr at gmail.com
Mon Jun 13 11:02:25 CEST 2016


This automated email contains information about 2 new commits which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
00761de4a3 SCI32: Remove the unused newColors array
a4ef3f9d73 SCI32: All versions of KQ7 are using the older remap range semantics


Commit: 00761de4a3059f77b76720973eef725d50eec87d
    https://github.com/scummvm/scummvm/commit/00761de4a3059f77b76720973eef725d50eec87d
Author: Filippos Karapetis (bluegr at gmail.com)
Date: 2016-06-13T12:01:28+03:00

Commit Message:
SCI32: Remove the unused newColors array

Changed paths:
    engines/sci/graphics/remap.cpp



diff --git a/engines/sci/graphics/remap.cpp b/engines/sci/graphics/remap.cpp
index e331eaf..6f9b96a 100644
--- a/engines/sci/graphics/remap.cpp
+++ b/engines/sci/graphics/remap.cpp
@@ -329,7 +329,6 @@ bool GfxRemap32::applyRemap(byte index) {
 	RemapParams *curRemap = &_remaps[index];
 	const bool *cycleMap = _palette->getCyclemap();
 	bool unmappedColors[NON_REMAPPED_COLOR_COUNT];
-	Color newColors[NON_REMAPPED_COLOR_COUNT];
 	bool changed = false;
 
 	Common::fill(unmappedColors, unmappedColors + NON_REMAPPED_COLOR_COUNT, false);
@@ -341,12 +340,6 @@ bool GfxRemap32::applyRemap(byte index) {
 			unmappedColors[i] = true;
 	}
 
-	int curColor = 0;
-	for (int i = 1; i < NON_REMAPPED_COLOR_COUNT; i++)  {
-		if (curRemap->colorChanged[i] && !unmappedColors[i])
-			newColors[curColor++] = curRemap->curColor[i];
-	}
-
 	for (int i = 1; i < NON_REMAPPED_COLOR_COUNT; i++)  {
 		Color targetColor = curRemap->targetColor[i];
 		bool colorChanged = curRemap->colorChanged[curRemap->remap[i]];


Commit: a4ef3f9d7305783a3cc8068cb5dbc978a7f22f1c
    https://github.com/scummvm/scummvm/commit/a4ef3f9d7305783a3cc8068cb5dbc978a7f22f1c
Author: Filippos Karapetis (bluegr at gmail.com)
Date: 2016-06-13T12:01:28+03:00

Commit Message:
SCI32: All versions of KQ7 are using the older remap range semantics

Changed paths:
    engines/sci/graphics/remap.cpp



diff --git a/engines/sci/graphics/remap.cpp b/engines/sci/graphics/remap.cpp
index 6f9b96a..ff49e52 100644
--- a/engines/sci/graphics/remap.cpp
+++ b/engines/sci/graphics/remap.cpp
@@ -117,8 +117,9 @@ GfxRemap32::GfxRemap32(GfxPalette32 *palette) : _palette(palette) {
 	_update = false;
 	_remapCount = 0;
 
-	// The remap range was 245 - 254 in SCI2, but was changed to 235 - 244 in SCI21 middle
-	_remapEndColor = (getSciVersion() >= SCI_VERSION_2_1_MIDDLE) ? 244 : 254;
+	// The remap range was 245 - 254 in SCI2, but was changed to 235 - 244 in SCI21 middle.
+	// All versions of KQ7 are using the older remap range semantics.
+	_remapEndColor = (getSciVersion() >= SCI_VERSION_2_1_MIDDLE || g_sci->getGameId() == GID_KQ7) ? 244 : 254;
 }
 
 void GfxRemap32::remapOff(byte color) {






More information about the Scummvm-git-logs mailing list